@@ -1,6 +1,6 @@
 package URI::Fast;
 
-our $XS_VERSION = our $VERSION = '0.47';
+our $XS_VERSION = our $VERSION = '0.48';
 $VERSION =~ tr/_//;
 
 use utf8;
@@ -758,24 +758,6 @@ is a non-reference value.
 
 See L<URI::Fast::Benchmarks>.
 
-=head1 FUTURE PLANS
-
-Some thoughts on future development for this module.
-
-=over
-
-=item Support for arbitrary binary data in query string
-
-Currently, queries are restricted to keys or key/value pairs and decoded into
-utf8 strings.
-
-=item Compat module
-
-Add a compatibility layer with URI that implements what functionality is
-possible and croaks loudly otherwise.
-
-=back
-
 =head1 SEE ALSO
 
 =over
